Gaul
======

.. image:: https://readthedocs.org/projects/gaul/badge/?version=latest&style=for-the-badge&color=5E81AC
  :target: https://gaul.readthedocs.io/

.. image:: https://img.shields.io/github/workflow/status/al-jshen/gaul/Tests?color=5E81AC&label=tests&style=for-the-badge
  :target: https://github.com/al-jshen/gaul/actions?workflow=Tests

.. image:: https://img.shields.io/codecov/c/github/al-jshen/gaul?color=62a69b&style=for-the-badge
  :target: https://codecov.io/gh/al-jshen/gaul
  
